@@ -154,6 +154,9 @@ def update_pos():
 
 def save_offset():
     update_offset()
+    laserController.x_offset = x_offset
+    laserController.y_offset = y_offset
+    laserController.z_offset = z_offset
     updateOffsetsFile(x=x_offset, y=y_offset, z=z_offset)
     message.set_text(f"Offset saved X: {x_offset} Y: {y_offset} Z: {z_offset}")
 
@@ -255,6 +258,10 @@ palette = [
     ('buttnf', 'white', 'dark blue', 'bold'),
 ]
 update_pos()
+
+# init movement distance text
+movement_distance_txt.set_text(("reverse", "Movement distance: {} mm".format(movement_distance)))
+
 loop = urwid.MainLoop(frame, palette, unhandled_input=show_or_exit)
 loop.run()
 print("Quitting...")
